@@ -41,7 +41,7 @@ class IPAddressPool(NamespacedResource):
 
     def to_dict(self) -> None:
         super().to_dict()
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             if not self.addresses:
                 raise MissingRequiredArgumentError(argument="addresses")
 
